==> spip_4.0.4.orig.tar.xz: ecrire/lang/public_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Página inicial do sítio',
	'article' => 'Artigo',
	'articles' => 'Artigos',
	'articles_auteur' => 'Artigos deste autor',
	'articles_populaires' => 'Artigos mais populares',
	'articles_rubrique' => 'Artigos desta rubrica',
	'aucun_article' => 'Nenhum artigo neste endereço',
	'aucun_auteur' => 'Nenhum autor neste endereço',
	'aucun_site' => 'Nenhum sítio neste endereço',
	'aucune_breve' => 'Nenhuma notícia neste endereço',
	'aucune_rubrique' => 'Nenhuma rubrica neste endereço',
	'auteur' => 'Autor',
	'autres' => 'Outros',
	'autres_breves' => 'Outras notícias',
	'autres_groupes_mots_clefs' => 'Outros grupos de palavras-chave',
	'autres_sites' => 'Outros sítios',

	// B
	'bonjour' => 'Bom dia',

	// C
	'commenter_site' => 'Comentar este sítio',
	'contact' => 'Contacto',
	'copie_document_impossible' => 'Impossível copiar este documento',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Última actualização',
	'dernieres_breves' => 'Últimas notícias',
	'derniers_articles' => 'Últimos artigos',
	'derniers_commentaires' => 'Últimos comentários',
	'derniers_messages_forum' => 'Últimas mensagens publicadas nos fóruns',

	// E
	'edition_mode_texte' => 'Edição apenas em modo de texto',
	'en_reponse' => 'Em resposta a :',
	'en_resume' => 'Em resumo',
	'envoyer_message' => 'Enviar uma mensagem',
	'espace_prive' => 'Área privada',

	// F
	'formats_acceptes' => 'Formatos válidos : @formats@.',

	// H
	'hierarchie_site' => 'Mapa do sítio',

	// J
	'jours' => 'dias',

	// L
	'lien_connecter' => 'Entrar',

	// M
	'meme_auteur' => 'Do mesmo autor',
	'meme_rubrique' => 'Na mesma rubrica',
	'memes_auteurs' => 'Dos mesmos autores',
	'message' => 'Mensagem',
	'messages_forum' => 'Mensagens de fórum',
	'messages_recents' => 'Mensagens de fóruns mais recentes',
	'mots_clef' => 'Palavra-chave',
	'mots_clefs' => 'Palavras-chave',
	'mots_clefs_meme_groupe' => 'Palavras-chave no mesmo grupo',

	// N
	'navigation' => 'Navegação',
	'nom' => 'Nome',
	'nouveautes' => 'As novidades',
	'nouveautes_web' => 'Novidades na Web',
	'nouveaux_articles' => 'Novos artigos',
	'nouvelles_breves' => 'Novas notícias',

	// P
	'page_precedente' => 'página anterior',
	'page_suivante' => 'página seguinte',
	'par_auteur' => 'por',
	'participer_site' => 'Pode participar na vida deste sítio e propor os seus próprios artigos, inscrevendo-se mais abaixo. Receberá imediatamente um email com os seus códigos de acesso ao espaço privado do sítio.',
	'plan_site' => 'Mapa do sítio',
	'popularite' => 'Popularidade',
	'poster_message' => 'Enviar uma mensagem',
	'proposer_site' => 'Você pode propor um sítio a adicionar a esta rubrica :',

	// R
	'repondre_article' => 'Comentar este artigo',
	'repondre_breve' => 'Comentar esta notícia',
	'resultats_recherche' => 'Resultados da pesquisa',
	'retour_debut_forums' => 'Regresso ao início dos fóruns',
	'rss_abonnement' => 'Copie o seguinte URL para o seu agregador de conteúdos:',
	'rss_abonnement_titre' => 'Subscrever',
	'rss_abonnement_titre_page' => 'Subscrever',
	'rss_explication' => 'Um "feed" RSS recolhe informação actualizada a partir de um sítio. Fornece o conteúdo das publicações ou comentários ou um extracto dos mesmos, bem como um link para as versões completas e outras informações. Este "feed" destina-se a ser lido por um agregador RSS.',
	'rss_explication_titre' => 'O que é um "feed RSS"?',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Assinaturas',
	'site_realise_avec_spip' => 'Sítio realizado com SPIP',
	'sites_web' => 'Sítios Web',
	'sous_rubriques' => 'Sub-rubricas',
	'spam' => 'Spam',
	'suite' => 'continuação',
	'sur_web' => 'Na Web',
	'syndiquer_rubrique' => 'Subscrever esta rubrica',
	'syndiquer_site' => 'Subscrever todo o sítio',

	// T
	'texte_lettre_information' => 'Eis a carta de informação do sítio',
	'texte_lettre_information_2' => 'Este sítio contém novos itens publicados desde',

	// V
	'ver_imprimer' => 'Versão para imprimir',
	'voir_en_ligne' => 'Ver online',
	'voir_squelette' => 'exibir o modelo desta página'
);

==> spip_4.4.6+dfsg.orig.tar.xz: ecrire/lang/public_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=pt
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Página inicial do sítio',
	'article' => 'Artigo',
	'articles' => 'Artigos',
	'articles_auteur' => 'Artigos deste autor',
	'articles_populaires' => 'Artigos mais populares',
	'articles_rubrique' => 'Artigos desta rubrica',
	'aucun_article' => 'Nenhum artigo neste endereço',
	'aucun_auteur' => 'Nenhum autor neste endereço',
	'aucun_site' => 'Nenhum sítio neste endereço',
	'aucune_breve' => 'Nenhuma notícia neste endereço',
	'aucune_rubrique' => 'Nenhuma rubrica neste endereço',
	'auteur' => 'Autor',
	'autres' => 'Outros',
	'autres_breves' => 'Outras notícias',
	'autres_groupes_mots_clefs' => 'Outros grupos de palavras-chave',
	'autres_sites' => 'Outros sítios',

	// B
	'bonjour' => 'Bom dia',

	// C
	'commenter_site' => 'Comentar este sítio',
	'contact' => 'Contacto',
	'copie_document_impossible' => 'Impossível copiar este documento',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Última actualização',
	'dernieres_breves' => 'Últimas notícias',
	'derniers_articles' => 'Últimos artigos',
	'derniers_commentaires' => 'Últimos comentários',
	'derniers_messages_forum' => 'Últimas mensagens publicadas nos fóruns',

	// E
	'edition_mode_texte' => 'Edição apenas em modo de texto',
	'en_reponse' => 'Em resposta a :',
	'en_resume' => 'Em resumo',
	'envoyer_message' => 'Enviar uma mensagem',
	'espace_prive' => 'Área privada',

	// F
	'formats_acceptes' => 'Formatos válidos : @formats@.',

	// H
	'hierarchie_site' => 'Mapa do sítio',

	// J
	'jours' => 'dias',

	// L
	'lien_connecter' => 'Entrar',

	// M
	'meme_auteur' => 'Do mesmo autor',
	'meme_rubrique' => 'Na mesma rubrica',
	'memes_auteurs' => 'Dos mesmos autores',
	'message' => 'Mensagem',
	'messages_forum' => 'Mensagens de fórum',
	'messages_recents' => 'Mensagens de fóruns mais recentes',
	'mots_clef' => 'Palavra-chave',
	'mots_clefs' => 'Palavras-chave',
	'mots_clefs_meme_groupe' => 'Palavras-chave no mesmo grupo',

	// N
	'navigation' => 'Navegação',
	'nom' => 'Nome',
	'nouveautes' => 'As novidades',
	'nouveautes_web' => 'Novidades na Web',
	'nouveaux_articles' => 'Novos artigos',
	'nouvelles_breves' => 'Novas notícias',

	// P
	'page_precedente' => 'página anterior',
	'page_suivante' => 'página seguinte',
	'par_auteur' => 'por',
	'participer_site' => 'Pode participar na vida deste sítio e propor os seus próprios artigos, inscrevendo-se mais abaixo. Receberá imediatamente um email com os seus códigos de acesso ao espaço privado do sítio.',
	'plan_site' => 'Mapa do sítio',
	'popularite' => 'Popularidade',
	'poster_message' => 'Enviar uma mensagem',
	'proposer_site' => 'Você pode propor um sítio a adicionar a esta rubrica :',

	// R
	'repondre_article' => 'Comentar este artigo',
	'repondre_breve' => 'Comentar esta notícia',
	'resultats_recherche' => 'Resultados da pesquisa',
	'retour_debut_forums' => 'Regresso ao início dos fóruns',
	'rss_abonnement' => 'Copie o seguinte URL para o seu agregador de conteúdos:',
	'rss_abonnement_titre' => 'Subscrever',
	'rss_abonnement_titre_page' => 'Subscrever',
	'rss_explication' => 'Um "feed" RSS recolhe informação actualizada a partir de um sítio. Fornece o conteúdo das publicações ou comentários ou um extracto dos mesmos, bem como um link para as versões completas e outras informações. Este "feed" destina-se a ser lido por um agregador RSS.',
	'rss_explication_titre' => 'O que é um "feed RSS"?',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Assinaturas',
	'site_realise_avec_spip' => 'Sítio realizado com SPIP',
	'sites_web' => 'Sítios Web',
	'sous_rubriques' => 'Sub-rubricas',
	'spam' => 'Spam',
	'suite' => 'continuação',
	'sur_web' => 'Na Web',
	'syndiquer_rubrique' => 'Subscrever esta rubrica',
	'syndiquer_site' => 'Subscrever todo o sítio',

	// T
	'texte_lettre_information' => 'Eis a carta de informação do sítio',
	'texte_lettre_information_2' => 'Este sítio contém novos itens publicados desde',

	// V
	'ver_imprimer' => 'Versão para imprimir',
	'voir_en_ligne' => 'Ver online',
	'voir_squelette' => 'exibir o modelo desta página',
];
